@@ -29,12 +29,12 @@
 class TQProgressDialog;
 class TQTimer;
 
-class KAction;
+class TDEAction;
 
 class Plugin_Calendar : public KIPI::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 
@@ -42,12 +42,12 @@ public:
                     const char* name,
                     const TQStringList &args);
     ~Plugin_Calendar();
-    virtual KIPI::Category category( KAction* action ) const;
+    virtual KIPI::Category category( TDEAction* action ) const;
     virtual void setup( TQWidget* widget );
 
 private:
     
-    KAction* m_calendarAction;
+    TDEAction* m_calendarAction;
     
 private slots:
 
