@@ -51,17 +51,17 @@ extern "C"
 
 #include <kcursor.h>
 #include <kdebug.h>
-#include <klistview.h>
-#include <klocale.h>
+#include <tdelistview.h>
+#include <tdelocale.h>
 #include <kurl.h>
 #include <kiconloader.h>
 #include <kprogress.h>
-#include <kio/renamedlg.h>
-#include <kmessagebox.h>
-#include <kconfig.h>
-#include <kapplication.h>
+#include <tdeio/renamedlg.h>
+#include <tdemessagebox.h>
+#include <tdeconfig.h>
+#include <tdeapplication.h>
 #include <khelpmenu.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
 
 // LibKDcraw includes.
@@ -96,7 +96,7 @@ BatchDialog::BatchDialog(TQWidget* /*parent*/)
 
     //---------------------------------------------
 
-    m_listView = new KListView(m_page);
+    m_listView = new TDEListView(m_page);
     m_listView->addColumn( i18n("Thumbnail") );
     m_listView->addColumn( i18n("Raw File") );
     m_listView->addColumn( i18n("Target File") );
@@ -135,7 +135,7 @@ BatchDialog::BatchDialog(TQWidget* /*parent*/)
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("RAW Image Converter"),
                                            0,
-                                           KAboutData::License_GPL,
+                                           TDEAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin to batch convert Raw images"),
                                            "(c) 2003-2005, Renchi Raju\n"
                                            "(c) 2006-2008, Gilles Caulier");
@@ -207,7 +207,7 @@ void BatchDialog::slotDefault()
 
 void BatchDialog::readSettings()
 {
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("RawConverter Settings");
 
     m_decodingSettingsBox->setWhiteBalance((KDcrawIface::RawDecodingSettings::WhiteBalance)
@@ -253,7 +253,7 @@ void BatchDialog::readSettings()
 
 void BatchDialog::saveSettings()
 {
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("RawConverter Settings");
 
     config.writeEntry("White Balance", m_decodingSettingsBox->whiteBalance());
@@ -287,7 +287,7 @@ void BatchDialog::saveSettings()
 
 void BatchDialog::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("rawconverter", "kipi-plugins");
+    TDEApplication::kApplication()->invokeHelp("rawconverter", "kipi-plugins");
 }
 
 void BatchDialog::slotUser1()
@@ -386,7 +386,7 @@ void BatchDialog::addItems(const TQStringList& itemList)
 
     KURL::List urlList;
 
-    TQPixmap pix(SmallIcon( "file_broken", KIcon::SizeLarge, KIcon::DisabledState ));
+    TQPixmap pix(SmallIcon( "file_broken", TDEIcon::SizeLarge, TDEIcon::DisabledState ));
 
     for (TQStringList::const_iterator  it = itemList.begin();
          it != itemList.end(); ++it) 
@@ -519,21 +519,21 @@ void BatchDialog::processed(const TQString& file, const TQString& tmpFile)
         struct stat statBuf;
         if (::stat(TQFile::encodeName(destFile), &statBuf) == 0) 
         {
-            KIO::RenameDlg dlg(this, i18n("Save Raw Image converted from '%1' as")
+            TDEIO::RenameDlg dlg(this, i18n("Save Raw Image converted from '%1' as")
                                      .arg(m_currentConvertItem->src),
                                tmpFile, destFile,
-                               KIO::RenameDlg_Mode(KIO::M_SINGLE | KIO::M_OVERWRITE | KIO::M_SKIP));
+                               TDEIO::RenameDlg_Mode(TDEIO::M_SINGLE | TDEIO::M_OVERWRITE | TDEIO::M_SKIP));
 
             switch (dlg.exec())
             {
-                case KIO::R_CANCEL:
-                case KIO::R_SKIP:
+                case TDEIO::R_CANCEL:
+                case TDEIO::R_SKIP:
                 {
                     destFile = TQString();
                     m_currentConvertItem->viewItem->setPixmap(1, SmallIcon("cancel"));
                     break;
                 }
-                case KIO::R_RENAME:
+                case TDEIO::R_RENAME:
                 {
                     destFile = dlg.newDestURL().path();
                     break;
